.. image:: https://user-images.githubusercontent.com/11671536/51515070-22241c00-1dc7-11e9-90d5-832f3caa5c70.png

"A Pandas-Centric ObsPy_ Expansion Pack"

|Coverage| |Supported Versions| |PyPI| |Conda| |DOI| |Licence|

Documentation_

Code_

Change_Log_

Contributing_

Support_

License_

About_

Code_of_Conduct_

If you find ObsPlus useful consider citing it:

Chambers, D. J., Boltz, M. S., & Chamberlain, C. J. (2021).
ObsPlus: A Pandas-centric ObsPy expansion pack.
Journal of Open Source Software, 6(60), 2696.


.. _About: https://github.com/niosh-mining/about
.. _ObsPy: https://github.com/obspy/obspy
.. _Documentation: https://niosh-mining.github.io/obsplus/versions/latest/index.html
.. _Support: https://niosh-mining.github.io/obsplus/versions/latest/notebooks/support.html
.. _Code: https://github.com/niosh-mining/obsplus
.. _Change_Log: https://github.com/niosh-mining/obsplus/CHANGELOG.txt
.. _License: https://choosealicense.com/licenses/lgpl-3.0/
.. _Code_of_Conduct: https://github.com/niosh-mining/obsplus/blob/master/.github/CODE_OF_CONDUCT.md
.. _Contributing: https://niosh-mining.github.io/obsplus/versions/latest/notebooks/contributing.html

.. |Coverage| image:: https://codecov.io/gh/niosh-mining/obsplus/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/niosh-mining/obsplus

.. |Supported Versions| image:: https://img.shields.io/pypi/pyversions/obsplus.svg
   :target: https://pypi.python.org/pypi/obsplus

.. |Licence| image:: https://www.gnu.org/graphics/lgplv3-88x31.png
   :target: https://www.gnu.org/licenses/lgpl.html

.. |PyPI| image:: https://pepy.tech/badge/obsplus
   :target: https://pepy.tech/project/obsplus

.. |Conda| image:: https://img.shields.io/conda/dn/conda-forge/obsplus?label=conda%20downloads
   :target: https://github.com/conda-forge/obsplus-feedstock

.. |DOI| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4544008.svg
   :target: https://doi.org/10.5281/zenodo.4544008
